@@ -53,9 +53,9 @@ from BibleOrgSys.Online.SwordInstallManager import SwordInstallManager
 # Biblelator imports
 if __name__ == '__main__':
     import sys
-    aboveAboveFolderPath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
-    if aboveAboveFolderPath not in sys.path:
-        sys.path.insert( 0, aboveAboveFolderPath )
+    aboveAboveFolderpath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderpath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderpath )
 from Biblelator.BiblelatorGlobals import DEFAULT, tkSTART, MAX_PSEUDOVERSES, errorBeep, \
         DATAFILES_FOLDERPATH, \
         DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, \
@@ -98,15 +98,15 @@ class SwordManager( Frame ):
         and use that to inform child windows of BCV movements.
     """
     global settings
-    def __init__( self, rootWindow, homeFolderPath, loggingFolderPath, iconImage, settings ):
+    def __init__( self, rootWindow, homeFolderpath, loggingFolderpath, iconImage, settings ):
         """
         Main app initialisation function.
 
         Creates the main menu and toolbar which includes the main BCV (book/chapter/verse) selector.
         """
         if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.__init__( {}, {}, {}, … )").format( rootWindow, homeFolderPath, loggingFolderPath ) )
-        self.rootWindow, self.homeFolderPath, self.loggingFolderPath, self.iconImage, self.settings = rootWindow, homeFolderPath, loggingFolderPath, iconImage, settings
+            vPrint( 'Quiet', debuggingThisModule, _("SwordManager.__init__( {}, {}, {}, … )").format( rootWindow, homeFolderpath, loggingFolderpath ) )
+        self.rootWindow, self.homeFolderpath, self.loggingFolderpath, self.iconImage, self.settings = rootWindow, homeFolderpath, loggingFolderpath, iconImage, settings
         self.parentApp = self # Yes, that's me, myself!
         self.starting = True
 
@@ -194,7 +194,7 @@ class SwordManager( Frame ):
         self.rootWindow.title( programNameVersion )
         self.minimumSize = MINIMUM_MAIN_SIZE
         self.rootWindow.minsize( *parseWindowSize( self.minimumSize ) )
-        if BibleOrgSysGlobals.debugFlag: self.setDebugText( "__init__ finished." )
+        if BibleOrgSysGlobals.debugFlag: self.setDebugText( "SwordManager.__init__ finished." )
         self.starting = False
         self.setReadyStatus()
     # end of SwordManager.__init__
@@ -987,7 +987,7 @@ class SwordManager( Frame ):
         filename = PROGRAM_NAME.replace('/','-').replace(':','_').replace('\\','_') + '_log.txt'
         tEW = TextEditWindow( self )
         #if windowGeometry: tEW.geometry( windowGeometry )
-        if not tEW.setPathAndFile( self.loggingFolderPath, filename ) \
+        if not tEW.setPathAndFile( self.loggingFolderpath, filename ) \
         or not tEW.loadText():
             tEW.doClose()
             showError( self, SHORT_PROGRAM_NAME, _("Sorry, unable to open log file") )
@@ -1161,7 +1161,7 @@ def openSwordManager( parent ):
         vPrint( 'Quiet', debuggingThisModule, _("SwordManager.openSwordManager( {} )").format( parent ) )
 
     myWin = tk.Toplevel( parent )
-    application = SwordManager( myWin, parent.homeFolderPath, parent.loggingFolderPath, parent.iconImage, parent.settings )
+    application = SwordManager( myWin, parent.homeFolderpath, parent.loggingFolderpath, parent.iconImage, parent.settings )
 # end of SwordManager.openSwordManager
 
 
@@ -1184,12 +1184,12 @@ def briefDemo() -> None:
     tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
     tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
 
-    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
+    homeFolderpath = BibleOrgSysGlobals.findHomeFolderpath()
+    loggingFolderpath = os.path.join( homeFolderpath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderpath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
     settings.load()
 
-    application = SwordManager( tkRootWindow, homeFolderPath, loggingFolderPath, iconImage, settings )
+    application = SwordManager( tkRootWindow, homeFolderpath, loggingFolderpath, iconImage, settings )
     # Calls to the window manager class (wm in Tk)
     #application.master.title( programNameVersion )
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
@@ -1219,12 +1219,12 @@ def fullDemo() -> None:
     tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
     tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
 
-    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
+    homeFolderpath = BibleOrgSysGlobals.findHomeFolderpath()
+    loggingFolderpath = os.path.join( homeFolderpath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderpath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
     settings.load()
 
-    application = SwordManager( tkRootWindow, homeFolderPath, loggingFolderPath, iconImage, settings )
+    application = SwordManager( tkRootWindow, homeFolderpath, loggingFolderpath, iconImage, settings )
     # Calls to the window manager class (wm in Tk)
     #application.master.title( programNameVersion )
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
@@ -1236,13 +1236,13 @@ def fullDemo() -> None:
     tkRootWindow.mainloop()
 # end of SwordManager.fulldemo
 
-def main( homeFolderPath, loggingFolderPath ) -> None:
+def main( homeFolderpath, loggingFolderpath ) -> None:
     """
     Main program to handle command line parameters and then run what they want.
     """
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
 
-    #vPrint( 'Quiet', debuggingThisModule, 'FP main', repr(homeFolderPath), repr(loggingFolderPath) )
+    #vPrint( 'Quiet', debuggingThisModule, 'FP main', repr(homeFolderpath), repr(loggingFolderpath) )
 
     numInstancesFound = 0
     if sys.platform == 'linux':
@@ -1288,7 +1288,7 @@ def main( homeFolderPath, loggingFolderPath ) -> None:
     iconImage = tk.PhotoImage( file=DATAFILES_FOLDERPATH.joinpath( 'Biblelator.gif' ) )
     tkRootWindow.tk.call( 'wm', 'iconphoto', tkRootWindow._w, iconImage )
     tkRootWindow.title( programNameVersion + ' ' + _('starting') + '…' )
-    application = SwordManager( tkRootWindow, homeFolderPath, loggingFolderPath, iconImage, None )
+    application = SwordManager( tkRootWindow, homeFolderpath, loggingFolderpath, iconImage, None )
     # Calls to the window manager class (wm in Tk)
     #application.master.title( programNameVersion )
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
@@ -1303,11 +1303,11 @@ def run() -> None:
     multiprocessing.freeze_support() # Multiprocessing support for frozen Windows executables
 
     # Configure basic set-up
-    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    # if homeFolderPath[-1] not in '/\\': homeFolderPath += '/'
-    # loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    loggingFolderPath = homeFolderPath.joinpath( DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    parser = BibleOrgSysGlobals.setup( SHORT_PROGRAM_NAME, PROGRAM_VERSION, loggingFolderPath=loggingFolderPath )
+    homeFolderpath = BibleOrgSysGlobals.findHomeFolderpath()
+    # if homeFolderpath[-1] not in '/\\': homeFolderpath += '/'
+    # loggingFolderpath = os.path.join( homeFolderpath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    loggingFolderpath = homeFolderpath.joinpath( DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    parser = BibleOrgSysGlobals.setup( SHORT_PROGRAM_NAME, PROGRAM_VERSION, loggingFolderpath=loggingFolderpath )
     parser.add_argument( '-o', '--override', type=str, metavar='INIFilename', dest='override', help="override use of Biblelator.ini set-up" )
     BibleOrgSysGlobals.addStandardOptionsAndProcess( parser )
     #vPrint( 'Quiet', debuggingThisModule, BibleOrgSysGlobals.commandLineArguments ); halt
@@ -1318,7 +1318,7 @@ def run() -> None:
         if sys.platform == "linux": vPrint( 'Quiet', debuggingThisModule, _("OS uname is"), os.uname() ) # gives about five fields
         vPrint( 'Quiet', debuggingThisModule, _("Running main…") )
 
-    main( homeFolderPath, loggingFolderPath )
+    main( homeFolderpath, loggingFolderpath )
 
     BibleOrgSysGlobals.closedown( PROGRAM_NAME, PROGRAM_VERSION )
 # end of SwordManager.run
