@@ -49,9 +49,9 @@ from BibleOrgSys.Formats.PickledBible import ZIPPED_PICKLE_FILENAME_END
 # Biblelator imports
 if __name__ == '__main__':
     import sys
-    aboveAboveFolderPath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
-    if aboveAboveFolderPath not in sys.path:
-        sys.path.insert( 0, aboveAboveFolderPath )
+    aboveAboveFolderpath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderpath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderpath )
 from Biblelator.BiblelatorGlobals import APP_NAME, DEFAULT, \
     DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, \
     MINIMUM_MAIN_SIZE, MAXIMUM_MAIN_SIZE, MAX_WINDOWS, MAX_RECENT_FILES, \
@@ -350,14 +350,14 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                 rw = self.openDBPBibleResourceWindow( thisStuff['ModuleAbbreviation'], windowGeometry )
                 #except: logging.critical( "Unable to read all DBPBibleResourceWindow {} settings".format( j ) )
             elif windowType == 'InternalBibleResourceWindow':
-                folderpath = thisStuff['BibleFolderPath']
+                folderpath = thisStuff['BibleFolderpath']
                 if folderpath[-1] not in '/\\' \
                 and not str(folderpath).endswith( ZIPPED_PICKLE_FILENAME_END ):
                     folderpath = f'{folderpath}/'
                 rw = self.openInternalBibleResourceWindow( folderpath, windowGeometry )
                 #except: logging.critical( "Unable to read all InternalBibleResourceWindow {} settings".format( j ) )
             elif windowType == 'HebrewBibleResourceWindow':
-                folderpath = thisStuff['BibleFolderPath']
+                folderpath = thisStuff['BibleFolderpath']
                 if folderpath[-1] not in '/\\' \
                 and not str(folderpath).endswith( ZIPPED_PICKLE_FILENAME_END ):
                     folderpath = f'{folderpath}/'
@@ -396,7 +396,7 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                             rw.openBox( boxType, boxSource )
 
             elif windowType == 'TSVBibleEditWindow':
-                try: folderpath = convertToPython( thisStuff['TSVFolderPath'] )
+                try: folderpath = convertToPython( thisStuff['TSVFolderpath'] )
                 except KeyError: folderpath = None
                 rw = self.openTSVEditWindow( folderpath, windowGeometry )
 
@@ -412,7 +412,7 @@ def applyGivenWindowsSettings( self, givenWindowsSettingsName ):
                 rw = self.openFileTextEditWindow( filepath, windowGeometry )
                 #except: logging.critical( "Unable to read all PlainTextEditWindow {} settings".format( j ) )
             elif windowType == 'BiblelatorUSFMBibleEditWindow':
-                folderpath = thisStuff['ProjectFolderPath']
+                folderpath = thisStuff['ProjectFolderpath']
                 if folderpath[-1] not in '/\\': folderpath = f'{folderpath}/'
                 rw = self.openBiblelatorBibleEditWindow( folderpath, thisStuff['EditMode'], windowGeometry )
                 #except: logging.critical( "Unable to read all BiblelatorUSFMBibleEditWindow {} settings".format( j ) )
@@ -515,12 +515,12 @@ def getCurrentChildWindowSettings( self ):
         elif appWin.windowType == 'DBPBibleResourceWindow':
             thisOne['ModuleAbbreviation'] = appWin.moduleID
         elif appWin.windowType == 'InternalBibleResourceWindow':
-            thisOne['BibleFolderPath'] = appWin.moduleID
+            thisOne['BibleFolderpath'] = appWin.moduleID
         elif appWin.windowType == 'HebrewBibleResourceWindow':
-            thisOne['BibleFolderPath'] = appWin.moduleID
+            thisOne['BibleFolderpath'] = appWin.moduleID
 
         elif appWin.windowType == 'TSVBibleEditWindow':
-            thisOne['TSVFolderPath'] = appWin.folderpath
+            thisOne['TSVFolderpath'] = appWin.folderpath
 
         elif appWin.windowType == 'BibleLexiconResourceWindow':
             thisOne['BibleLexiconPath'] = appWin.moduleID
@@ -536,7 +536,7 @@ def getCurrentChildWindowSettings( self ):
             except AttributeError: pass # It's possible to have a blank new text edit window open
 
         elif appWin.windowType == 'BiblelatorUSFMBibleEditWindow':
-            thisOne['ProjectFolderPath'] = appWin.moduleID
+            thisOne['ProjectFolderpath'] = appWin.moduleID
             thisOne['EditMode'] = appWin.editMode
         elif appWin.windowType == 'Paratext8USFMBibleEditWindow':
             thisOne['ProjectFolder'] = appWin.moduleID
@@ -822,10 +822,10 @@ def doSendUsageStatistics( self ):
 
     # Add log file(s)
     filename = adjAppName + '_log.txt'
-    #vPrint( 'Quiet', debuggingThisModule, "zipF1", repr(self.loggingFolderPath) )
+    #vPrint( 'Quiet', debuggingThisModule, "zipF1", repr(self.loggingFolderpath) )
     #vPrint( 'Quiet', debuggingThisModule, "zipF2", repr(filename) )
     for extension in BibleOrgSysGlobals.STANDARD_BACKUP_EXTENSIONS:
-        filepath = os.path.join( self.loggingFolderPath, filename+extension )
+        filepath = os.path.join( self.loggingFolderpath, filename+extension )
         #vPrint( 'Quiet', debuggingThisModule, "  zipF3", repr(filepath) )
         if os.path.exists( filepath ):
             #vPrint( 'Quiet', debuggingThisModule, "  zipF4", repr(filepath) )
@@ -908,12 +908,12 @@ def briefDemo() -> None:
         vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
     tkRootWindow.title( programNameVersion )
 
-    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, APP_NAME )
+    homeFolderpath = BibleOrgSysGlobals.findHomeFolderpath()
+    loggingFolderpath = os.path.join( homeFolderpath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderpath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, APP_NAME )
     settings.load()
 
-    application = Application( tkRootWindow, homeFolderPath, loggingFolderPath, settings )
+    application = Application( tkRootWindow, homeFolderpath, loggingFolderpath, settings )
     # Calls to the window manager class (wm in Tk)
     #application.master.title( programNameVersion )
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
@@ -944,12 +944,12 @@ def fullDemo() -> None:
         vPrint( 'Quiet', debuggingThisModule, 'Windowing system is', repr( tkRootWindow.tk.call('tk', 'windowingsystem') ) )
     tkRootWindow.title( programNameVersion )
 
-    homeFolderPath = BibleOrgSysGlobals.findHomeFolderPath()
-    loggingFolderPath = os.path.join( homeFolderPath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
-    settings = ApplicationSettings( homeFolderPath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, APP_NAME )
+    homeFolderpath = BibleOrgSysGlobals.findHomeFolderpath()
+    loggingFolderpath = os.path.join( homeFolderpath, DATA_FOLDER_NAME, LOGGING_SUBFOLDER_NAME )
+    settings = ApplicationSettings( homeFolderpath, DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, APP_NAME )
     settings.load()
 
-    application = Application( tkRootWindow, homeFolderPath, loggingFolderPath, settings )
+    application = Application( tkRootWindow, homeFolderpath, loggingFolderpath, settings )
     # Calls to the window manager class (wm in Tk)
     #application.master.title( programNameVersion )
     #application.master.minsize( application.minimumXSize, application.minimumYSize )
